pub struct DriverDispatcherRef<'a>(/* private fields */);Expand description
An unowned reference to a driver runtime dispatcher such as is produced by calling
Dispatcher::release. When this object goes out of scope it won’t shut down the dispatcher,
leaving that up to the driver runtime or another owner.
Implementations
Sourceimpl<'a> DriverDispatcherRef<'a>
impl<'a> DriverDispatcherRef<'a>
Sourcepub unsafe fn from_raw(
handle: NonNull<fdf_dispatcher>,
) -> DriverDispatcherRef<'a>
pub unsafe fn from_raw( handle: NonNull<fdf_dispatcher>, ) -> DriverDispatcherRef<'a>
Creates a dispatcher ref from a raw handle.
Safety
Caller is responsible for ensuring that the given handle is valid for
the lifetime 'a.
Sourcepub fn from_async_dispatcher(
dispatcher: AsyncDispatcherRef<'a>,
) -> DriverDispatcherRef<'a>
pub fn from_async_dispatcher( dispatcher: AsyncDispatcherRef<'a>, ) -> DriverDispatcherRef<'a>
Creates a dispatcher ref from an AsyncDispatcherRef.
Panics
Note that this will cause an assert if the AsyncDispatcherRef was not created from a
driver dispatcher in the first place.
Sourcepub unsafe fn as_raw(&mut self) -> *mut fdf_dispatcher
pub unsafe fn as_raw(&mut self) -> *mut fdf_dispatcher
Gets the raw handle from this dispatcher ref.
Safety
Caller is responsible for ensuring that the dispatcher handle is used safely.
Sourcepub fn always_on_dispatcher(&self) -> DriverDispatcherRef<'a>
pub fn always_on_dispatcher(&self) -> DriverDispatcherRef<'a>
Returns a [DispatcherRef] for the always-on dispatcher associated with this dispatcher,
preserving the lifetime parameter of the parent dispatcher.
Methods from Deref<Target = Dispatcher>
Sourcepub fn is_unsynchronized(&self) -> bool
pub fn is_unsynchronized(&self) -> bool
Whether this dispatcher’s tasks and futures can run on multiple threads at the same time.
Sourcepub fn allows_thread_blocking(&self) -> bool
pub fn allows_thread_blocking(&self) -> bool
Whether this dispatcher is allowed to call blocking functions or not
Sourcepub fn allows_thread_migration(&self) -> bool
pub fn allows_thread_migration(&self) -> bool
Whether this dispatcher is allowed to migrate threads, in which case it can’t
be used for non-Send tasks.
Sourcepub fn is_current_dispatcher(&self) -> bool
pub fn is_current_dispatcher(&self) -> bool
Whether this is the dispatcher the current thread is running on
Sourcepub fn as_dispatcher_ref(&self) -> DriverDispatcherRef<'_>
pub fn as_dispatcher_ref(&self) -> DriverDispatcherRef<'_>
Returns a [DispatcherRef] that references this dispatcher with a lifetime constrained by
self.