AutoReleaseDispatcher

Struct AutoReleaseDispatcher 

pub struct AutoReleaseDispatcher { /* private fields */ }
An owned reference to a driver runtime dispatcher that auto-releases when dropped. This gives you the best of both worlds of having an Arc<Dispatcher> and a DispatcherRef<'static> created by Dispatcher::release:

  • You can vend [Weak]-like pointers to it that will not cause memory access errors if used after the dispatcher has shut down, like an [Arc].
  • You can tie its terminal lifetime to that of the driver itself.

This is particularly useful in tests.

Implementations

Source

impl AutoReleaseDispatcher

pub unsafe fn from_raw( dispatcher: NonNull<fdf_dispatcher>, ) -> AutoReleaseDispatcher

Creates a dispatcher ref from a raw handle.

Safety

Caller is responsible for ensuring that the given handle is valid and not owned by any other wrapper that will free it at an arbitrary time.

pub fn as_async_dispatcher(&self) -> AsyncDispatcher

Returns a weakened reference to this dispatcher. This weak reference will only be valid so long as the dispatcher is shutting down, after which it will no longer be usable to spawn tasks on.

pub fn as_dispatcher_ref(&self) -> DriverDispatcherRef<'_>

Returns a [DispatcherRef] that references this dispatcher with a lifetime constrained by self.

pub fn always_on_dispatcher(&self) -> AutoReleaseDispatcher

Returns the Always-On interface of this dispatcher.